@@ -5,31 +5,36 @@
 #pragma once
 
 #include "cell.h"
-#include <xtensor/xarray.hpp>
-#include <xtensor/xtensor.hpp>
+#include "mdspan.hpp"
+#include <array>
+#include <utility>
+#include <vector>
 
 /// Polynomials
 namespace basix::polynomials
 {
-/// An enum defining the variants of a Lagrange space that can be created
+/// Variants of a Lagrange space that can be created
 enum class type
 {
   legendre = 0,
+  bernstein = 1,
 };
 
-/// Tabulate a set of polynomials.
-///
+/// @brief Tabulate a set of polynomials.
 /// @param[in] polytype Polynomial type
 /// @param[in] celltype Cell type
 /// @param[in] d Polynomial degree
 /// @param[in] x Points at which to evaluate the basis. The shape is
 /// (number of points, geometric dimension).
 /// @return Polynomial sets, for each derivative, tabulated at points.
-/// The shape is `(number of points, basis index)`.
-xt::xtensor<double, 2> tabulate(polynomials::type polytype, cell::type celltype,
-                                int d, const xt::xarray<double>& x);
+/// The shape is `(basis index, number of points)`.
+std::pair<std::vector<double>, std::array<std::size_t, 2>>
+tabulate(polynomials::type polytype, cell::type celltype, int d,
+         std::experimental::mdspan<const double,
+                                   std::experimental::dextents<std::size_t, 2>>
+             x);
 
-/// Dimension of a polynomial space
+/// @brief Dimension of a polynomial space.
 /// @param[in] polytype The polynomial type
 /// @param[in] cell The cell type
 /// @param[in] d The polynomial degree
