@@ -9,75 +9,180 @@ import sympy
 
 
 def sympy_lagrange(celltype, n):
+    # These basis functions were computed using symfem. They can be recomputed
+    # by running (eg):
+    #    import symfem
+    #    e = symfem.create_element("triangle", "Lagrange", 2)
+    #    print(e.get_basis_functions())
     x = sympy.Symbol("x")
     y = sympy.Symbol("y")
     z = sympy.Symbol("z")
 
-    from sympy import S
-    topology = basix.topology(celltype)
-    geometry = S(basix.geometry(celltype).astype(int))
-    pt = []
-    for dim, entities in enumerate(topology):
-        for ent in entities:
-            entity_geom = [geometry[t, :] for t in ent]
-
-            if (dim == 0):
-                pt += [entity_geom[0]]
-            elif (dim == 1):
-                for i in range(n - 1):
-                    pt += [entity_geom[0]
-                           + sympy.Rational(i + 1, n) * (entity_geom[1] - entity_geom[0])]
-            elif (dim == 2):
-                for i in range(n - 2):
-                    for j in range(n - 2 - i):
-                        pt += [entity_geom[0]
-                               + sympy.Rational(i + 1, n) * (entity_geom[2] - entity_geom[0])
-                               + sympy.Rational(j + 1, n) * (entity_geom[1] - entity_geom[0])]
-            elif (dim == 3):
-                for i in range(n - 3):
-                    for j in range(n - 3 - i):
-                        for k in range(n - 3 - i - j):
-                            pt += [entity_geom[0]
-                                   + sympy.Rational(i + 1, n) * (entity_geom[3] - entity_geom[0])
-                                   + sympy.Rational(j + 1, n) * (entity_geom[2] - entity_geom[0])
-                                   + sympy.Rational(k + 1, n) * (entity_geom[1] - entity_geom[0])]
-
-    funcs = []
     if celltype == basix.CellType.interval:
-        for i in range(n + 1):
-            funcs += [x**i]
+        if n == 1:
+            return [1 - x, x]
+        if n == 2:
+            return [2*x**2 - 3*x + 1, 2*x**2 - x, -4*x**2 + 4*x]
+        if n == 3:
+            return [-9*x**3/2 + 9*x**2 - 11*x/2 + 1,
+                    9*x**3/2 - 9*x**2/2 + x,
+                    27*x**3/2 - 45*x**2/2 + 9*x,
+                    -27*x**3/2 + 18*x**2 - 9*x/2]
+        if n == 4:
+            return [32*x**4/3 - 80*x**3/3 + 70*x**2/3 - 25*x/3 + 1,
+                    32*x**4/3 - 16*x**3 + 22*x**2/3 - x,
+                    -128*x**4/3 + 96*x**3 - 208*x**2/3 + 16*x,
+                    64*x**4 - 128*x**3 + 76*x**2 - 12*x,
+                    -128*x**4/3 + 224*x**3/3 - 112*x**2/3 + 16*x/3]
+        if n == 5:
+            return [-625*x**5/24 + 625*x**4/8 - 2125*x**3/24 + 375*x**2/8 - 137*x/12 + 1,
+                    625*x**5/24 - 625*x**4/12 + 875*x**3/24 - 125*x**2/12 + x,
+                    3125*x**5/24 - 4375*x**4/12 + 8875*x**3/24 - 1925*x**2/12 + 25*x,
+                    -3125*x**5/12 + 8125*x**4/12 - 7375*x**3/12 + 2675*x**2/12 - 25*x,
+                    3125*x**5/12 - 625*x**4 + 6125*x**3/12 - 325*x**2/2 + 50*x/3,
+                    -3125*x**5/24 + 6875*x**4/24 - 5125*x**3/24 + 1525*x**2/24 - 25*x/4]
+    if celltype == basix.CellType.triangle:
+        if n == 1:
+            return [-x - y + 1, x, y]
+        if n == 2:
+            return [2*x**2 + 4*x*y - 3*x + 2*y**2 - 3*y + 1,
+                    2*x**2 - x,
+                    2*y**2 - y,
+                    4*x*y,
+                    -4*x*y - 4*y**2 + 4*y,
+                    -4*x**2 - 4*x*y + 4*x]
+        if n == 3:
+            return [
+                -9*x**3/2 - 27*x**2*y/2 + 9*x**2 - 27*x*y**2/2 + 18*x*y - 11*x/2 - 9*y**3/2 + 9*y**2 - 11*y/2 + 1,
+                9*x**3/2 - 9*x**2/2 + x,
+                9*y**3/2 - 9*y**2/2 + y,
+                27*x**2*y/2 - 9*x*y/2,
+                27*x*y**2/2 - 9*x*y/2,
+                27*x**2*y/2 + 27*x*y**2 - 45*x*y/2 + 27*y**3/2 - 45*y**2/2 + 9*y,
+                -27*x*y**2/2 + 9*x*y/2 - 27*y**3/2 + 18*y**2 - 9*y/2,
+                27*x**3/2 + 27*x**2*y - 45*x**2/2 + 27*x*y**2/2 - 45*x*y/2 + 9*x,
+                -27*x**3/2 - 27*x**2*y/2 + 18*x**2 + 9*x*y/2 - 9*x/2,
+                -27*x**2*y - 27*x*y**2 + 27*x*y
+            ]
+        if n == 4:
+            return [
+                32*x**4/3 + 128*x**3*y/3 - 80*x**3/3 + 64*x**2*y**2 - 80*x**2*y + 70*x**2/3 + 128*x*y**3/3 - 80*x*y**2 + 140*x*y/3 - 25*x/3 + 32*y**4/3 - 80*y**3/3 + 70*y**2/3 - 25*y/3 + 1,  # noqa: E501
+                32*x**4/3 - 16*x**3 + 22*x**2/3 - x,
+                32*y**4/3 - 16*y**3 + 22*y**2/3 - y,
+                128*x**3*y/3 - 32*x**2*y + 16*x*y/3,
+                64*x**2*y**2 - 16*x**2*y - 16*x*y**2 + 4*x*y,
+                128*x*y**3/3 - 32*x*y**2 + 16*x*y/3,
+                -128*x**3*y/3 - 128*x**2*y**2 + 96*x**2*y - 128*x*y**3 + 192*x*y**2 - 208*x*y/3 - 128*y**4/3 + 96*y**3 - 208*y**2/3 + 16*y,  # noqa: E501
+                64*x**2*y**2 - 16*x**2*y + 128*x*y**3 - 144*x*y**2 + 28*x*y + 64*y**4 - 128*y**3 + 76*y**2 - 12*y,
+                -128*x*y**3/3 + 32*x*y**2 - 16*x*y/3 - 128*y**4/3 + 224*y**3/3 - 112*y**2/3 + 16*y/3,
+                -128*x**4/3 - 128*x**3*y + 96*x**3 - 128*x**2*y**2 + 192*x**2*y - 208*x**2/3 - 128*x*y**3/3 + 96*x*y**2 - 208*x*y/3 + 16*x,  # noqa: E501
+                64*x**4 + 128*x**3*y - 128*x**3 + 64*x**2*y**2 - 144*x**2*y + 76*x**2 - 16*x*y**2 + 28*x*y - 12*x,
+                -128*x**4/3 - 128*x**3*y/3 + 224*x**3/3 + 32*x**2*y - 112*x**2/3 - 16*x*y/3 + 16*x/3,
+                128*x**3*y + 256*x**2*y**2 - 224*x**2*y + 128*x*y**3 - 224*x*y**2 + 96*x*y,
+                -128*x**3*y - 128*x**2*y**2 + 160*x**2*y + 32*x*y**2 - 32*x*y,
+                -128*x**2*y**2 + 32*x**2*y - 128*x*y**3 + 160*x*y**2 - 32*x*y
+            ]
+        if n == 5:
+            return [
+                -625*x**5/24 - 3125*x**4*y/24 + 625*x**4/8 - 3125*x**3*y**2/12 + 625*x**3*y/2 - 2125*x**3/24 - 3125*x**2*y**3/12 + 1875*x**2*y**2/4 - 2125*x**2*y/8 + 375*x**2/8 - 3125*x*y**4/24 + 625*x*y**3/2 - 2125*x*y**2/8 + 375*x*y/4 - 137*x/12 - 625*y**5/24 + 625*y**4/8 - 2125*y**3/24 + 375*y**2/8 - 137*y/12 + 1,  # noqa: E501
+                625*x**5/24 - 625*x**4/12 + 875*x**3/24 - 125*x**2/12 + x,
+                625*y**5/24 - 625*y**4/12 + 875*y**3/24 - 125*y**2/12 + y,
+                3125*x**4*y/24 - 625*x**3*y/4 + 1375*x**2*y/24 - 25*x*y/4,
+                3125*x**3*y**2/12 - 625*x**3*y/12 - 625*x**2*y**2/4 + 125*x**2*y/4 + 125*x*y**2/6 - 25*x*y/6,
+                3125*x**2*y**3/12 - 625*x**2*y**2/4 + 125*x**2*y/6 - 625*x*y**3/12 + 125*x*y**2/4 - 25*x*y/6,
+                3125*x*y**4/24 - 625*x*y**3/4 + 1375*x*y**2/24 - 25*x*y/4,
+                3125*x**4*y/24 + 3125*x**3*y**2/6 - 4375*x**3*y/12 + 3125*x**2*y**3/4 - 4375*x**2*y**2/4 + 8875*x**2*y/24 + 3125*x*y**4/6 - 4375*x*y**3/4 + 8875*x*y**2/12 - 1925*x*y/12 + 3125*y**5/24 - 4375*y**4/12 + 8875*y**3/24 - 1925*y**2/12 + 25*y,  # noqa: E501
+                -3125*x**3*y**2/12 + 625*x**3*y/12 - 3125*x**2*y**3/4 + 3125*x**2*y**2/4 - 125*x**2*y - 3125*x*y**4/4 + 5625*x*y**3/4 - 8875*x*y**2/12 + 1175*x*y/12 - 3125*y**5/12 + 8125*y**4/12 - 7375*y**3/12 + 2675*y**2/12 - 25*y,  # noqa: E501
+                3125*x**2*y**3/12 - 625*x**2*y**2/4 + 125*x**2*y/6 + 3125*x*y**4/6 - 3125*x*y**3/4 + 3875*x*y**2/12 - 75*x*y/2 + 3125*y**5/12 - 625*y**4 + 6125*y**3/12 - 325*y**2/2 + 50*y/3,  # noqa: E501
+                -3125*x*y**4/24 + 625*x*y**3/4 - 1375*x*y**2/24 + 25*x*y/4 - 3125*y**5/24 + 6875*y**4/24 - 5125*y**3/24 + 1525*y**2/24 - 25*y/4,  # noqa: E501
+                3125*x**5/24 + 3125*x**4*y/6 - 4375*x**4/12 + 3125*x**3*y**2/4 - 4375*x**3*y/4 + 8875*x**3/24 + 3125*x**2*y**3/6 - 4375*x**2*y**2/4 + 8875*x**2*y/12 - 1925*x**2/12 + 3125*x*y**4/24 - 4375*x*y**3/12 + 8875*x*y**2/24 - 1925*x*y/12 + 25*x,  # noqa: E501
+                -3125*x**5/12 - 3125*x**4*y/4 + 8125*x**4/12 - 3125*x**3*y**2/4 + 5625*x**3*y/4 - 7375*x**3/12 - 3125*x**2*y**3/12 + 3125*x**2*y**2/4 - 8875*x**2*y/12 + 2675*x**2/12 + 625*x*y**3/12 - 125*x*y**2 + 1175*x*y/12 - 25*x,  # noqa: E501
+                3125*x**5/12 + 3125*x**4*y/6 - 625*x**4 + 3125*x**3*y**2/12 - 3125*x**3*y/4 + 6125*x**3/12 - 625*x**2*y**2/4 + 3875*x**2*y/12 - 325*x**2/2 + 125*x*y**2/6 - 75*x*y/2 + 50*x/3,  # noqa: E501
+                -3125*x**5/24 - 3125*x**4*y/24 + 6875*x**4/24 + 625*x**3*y/4 - 5125*x**3/24 - 1375*x**2*y/24 + 1525*x**2/24 + 25*x*y/4 - 25*x/4,  # noqa: E501
+                -3125*x**4*y/6 - 3125*x**3*y**2/2 + 1250*x**3*y - 3125*x**2*y**3/2 + 2500*x**2*y**2 - 5875*x**2*y/6 - 3125*x*y**4/6 + 1250*x*y**3 - 5875*x*y**2/6 + 250*x*y,  # noqa: E501
+                3125*x**4*y/4 + 3125*x**3*y**2/2 - 3125*x**3*y/2 + 3125*x**2*y**3/4 - 6875*x**2*y**2/4 + 3625*x**2*y/4 - 625*x*y**3/4 + 1125*x*y**2/4 - 125*x*y,  # noqa: E501
+                -3125*x**4*y/6 - 3125*x**3*y**2/6 + 2500*x**3*y/3 + 625*x**2*y**2/2 - 2125*x**2*y/6 - 125*x*y**2/3 + 125*x*y/3,  # noqa: E501
+                3125*x**3*y**2/4 - 625*x**3*y/4 + 3125*x**2*y**3/2 - 6875*x**2*y**2/4 + 1125*x**2*y/4 + 3125*x*y**4/4 - 3125*x*y**3/2 + 3625*x*y**2/4 - 125*x*y,  # noqa: E501
+                -3125*x**3*y**2/4 + 625*x**3*y/4 - 3125*x**2*y**3/4 + 4375*x**2*y**2/4 - 375*x**2*y/2 + 625*x*y**3/4 - 375*x*y**2/2 + 125*x*y/4,  # noqa: E501
+                -3125*x**2*y**3/6 + 625*x**2*y**2/2 - 125*x**2*y/3 - 3125*x*y**4/6 + 2500*x*y**3/3 - 2125*x*y**2/6 + 125*x*y/3  # noqa: E501
+            ]
+    if celltype == basix.CellType.tetrahedron:
+        if n == 1:
+            return [-x - y - z + 1, x, y, z]
+        if n == 2:
+            return [2*x**2 + 4*x*y + 4*x*z - 3*x + 2*y**2 + 4*y*z - 3*y + 2*z**2 - 3*z + 1,
+                    2*x**2 - x,
+                    2*y**2 - y,
+                    2*z**2 - z,
+                    4*y*z,
+                    4*x*z,
+                    4*x*y,
+                    -4*x*z - 4*y*z - 4*z**2 + 4*z,
+                    -4*x*y - 4*y**2 - 4*y*z + 4*y,
+                    -4*x**2 - 4*x*y - 4*x*z + 4*x]
+        if n == 3:
+            return [
+                -9*x**3/2 - 27*x**2*y/2 - 27*x**2*z/2 + 9*x**2 - 27*x*y**2/2 - 27*x*y*z + 18*x*y - 27*x*z**2/2 + 18*x*z - 11*x/2 - 9*y**3/2 - 27*y**2*z/2 + 9*y**2 - 27*y*z**2/2 + 18*y*z - 11*y/2 - 9*z**3/2 + 9*z**2 - 11*z/2 + 1,  # noqa: E501
+                9*x**3/2 - 9*x**2/2 + x,
+                9*y**3/2 - 9*y**2/2 + y,
+                9*z**3/2 - 9*z**2/2 + z,
+                27*y**2*z/2 - 9*y*z/2,
+                27*y*z**2/2 - 9*y*z/2,
+                27*x**2*z/2 - 9*x*z/2,
+                27*x*z**2/2 - 9*x*z/2,
+                27*x**2*y/2 - 9*x*y/2,
+                27*x*y**2/2 - 9*x*y/2,
+                27*x**2*z/2 + 27*x*y*z + 27*x*z**2 - 45*x*z/2 + 27*y**2*z/2 + 27*y*z**2 - 45*y*z/2 + 27*z**3/2 - 45*z**2/2 + 9*z,  # noqa: E501
+                -27*x*z**2/2 + 9*x*z/2 - 27*y*z**2/2 + 9*y*z/2 - 27*z**3/2 + 18*z**2 - 9*z/2,
+                27*x**2*y/2 + 27*x*y**2 + 27*x*y*z - 45*x*y/2 + 27*y**3/2 + 27*y**2*z - 45*y**2/2 + 27*y*z**2/2 - 45*y*z/2 + 9*y,  # noqa: E501
+                -27*x*y**2/2 + 9*x*y/2 - 27*y**3/2 - 27*y**2*z/2 + 18*y**2 + 9*y*z/2 - 9*y/2,
+                27*x**3/2 + 27*x**2*y + 27*x**2*z - 45*x**2/2 + 27*x*y**2/2 + 27*x*y*z - 45*x*y/2 + 27*x*z**2/2 - 45*x*z/2 + 9*x,  # noqa: E501
+                -27*x**3/2 - 27*x**2*y/2 - 27*x**2*z/2 + 18*x**2 + 9*x*y/2 + 9*x*z/2 - 9*x/2,
+                27*x*y*z,
+                -27*x*y*z - 27*y**2*z - 27*y*z**2 + 27*y*z,
+                -27*x**2*z - 27*x*y*z - 27*x*z**2 + 27*x*z,
+                -27*x**2*y - 27*x*y**2 - 27*x*y*z + 27*x*y
+            ]
+        if n == 4:
+            return [
+                32*x**4/3 + 128*x**3*y/3 + 128*x**3*z/3 - 80*x**3/3 + 64*x**2*y**2 + 128*x**2*y*z - 80*x**2*y + 64*x**2*z**2 - 80*x**2*z + 70*x**2/3 + 128*x*y**3/3 + 128*x*y**2*z - 80*x*y**2 + 128*x*y*z**2 - 160*x*y*z + 140*x*y/3 + 128*x*z**3/3 - 80*x*z**2 + 140*x*z/3 - 25*x/3 + 32*y**4/3 + 128*y**3*z/3 - 80*y**3/3 + 64*y**2*z**2 - 80*y**2*z + 70*y**2/3 + 128*y*z**3/3 - 80*y*z**2 + 140*y*z/3 - 25*y/3 + 32*z**4/3 - 80*z**3/3 + 70*z**2/3 - 25*z/3 + 1,  # noqa: E501
+                32*x**4/3 - 16*x**3 + 22*x**2/3 - x,
+                32*y**4/3 - 16*y**3 + 22*y**2/3 - y,
+                32*z**4/3 - 16*z**3 + 22*z**2/3 - z,
+                128*y**3*z/3 - 32*y**2*z + 16*y*z/3,
+                64*y**2*z**2 - 16*y**2*z - 16*y*z**2 + 4*y*z,
+                128*y*z**3/3 - 32*y*z**2 + 16*y*z/3,
+                128*x**3*z/3 - 32*x**2*z + 16*x*z/3,
+                64*x**2*z**2 - 16*x**2*z - 16*x*z**2 + 4*x*z,
+                128*x*z**3/3 - 32*x*z**2 + 16*x*z/3,
+                128*x**3*y/3 - 32*x**2*y + 16*x*y/3,
+                64*x**2*y**2 - 16*x**2*y - 16*x*y**2 + 4*x*y,
+                128*x*y**3/3 - 32*x*y**2 + 16*x*y/3,
+                -128*x**3*z/3 - 128*x**2*y*z - 128*x**2*z**2 + 96*x**2*z - 128*x*y**2*z - 256*x*y*z**2 + 192*x*y*z - 128*x*z**3 + 192*x*z**2 - 208*x*z/3 - 128*y**3*z/3 - 128*y**2*z**2 + 96*y**2*z - 128*y*z**3 + 192*y*z**2 - 208*y*z/3 - 128*z**4/3 + 96*z**3 - 208*z**2/3 + 16*z,  # noqa: E501
+                64*x**2*z**2 - 16*x**2*z + 128*x*y*z**2 - 32*x*y*z + 128*x*z**3 - 144*x*z**2 + 28*x*z + 64*y**2*z**2 - 16*y**2*z + 128*y*z**3 - 144*y*z**2 + 28*y*z + 64*z**4 - 128*z**3 + 76*z**2 - 12*z,  # noqa: E501
+                -128*x*z**3/3 + 32*x*z**2 - 16*x*z/3 - 128*y*z**3/3 + 32*y*z**2 - 16*y*z/3 - 128*z**4/3 + 224*z**3/3 - 112*z**2/3 + 16*z/3,  # noqa: E501
+                -128*x**3*y/3 - 128*x**2*y**2 - 128*x**2*y*z + 96*x**2*y - 128*x*y**3 - 256*x*y**2*z + 192*x*y**2 - 128*x*y*z**2 + 192*x*y*z - 208*x*y/3 - 128*y**4/3 - 128*y**3*z + 96*y**3 - 128*y**2*z**2 + 192*y**2*z - 208*y**2/3 - 128*y*z**3/3 + 96*y*z**2 - 208*y*z/3 + 16*y,  # noqa: E501
+                64*x**2*y**2 - 16*x**2*y + 128*x*y**3 + 128*x*y**2*z - 144*x*y**2 - 32*x*y*z + 28*x*y + 64*y**4 + 128*y**3*z - 128*y**3 + 64*y**2*z**2 - 144*y**2*z + 76*y**2 - 16*y*z**2 + 28*y*z - 12*y,  # noqa: E501
+                -128*x*y**3/3 + 32*x*y**2 - 16*x*y/3 - 128*y**4/3 - 128*y**3*z/3 + 224*y**3/3 + 32*y**2*z - 112*y**2/3 - 16*y*z/3 + 16*y/3,  # noqa: E501
+                -128*x**4/3 - 128*x**3*y - 128*x**3*z + 96*x**3 - 128*x**2*y**2 - 256*x**2*y*z + 192*x**2*y - 128*x**2*z**2 + 192*x**2*z - 208*x**2/3 - 128*x*y**3/3 - 128*x*y**2*z + 96*x*y**2 - 128*x*y*z**2 + 192*x*y*z - 208*x*y/3 - 128*x*z**3/3 + 96*x*z**2 - 208*x*z/3 + 16*x,  # noqa: E501
+                64*x**4 + 128*x**3*y + 128*x**3*z - 128*x**3 + 64*x**2*y**2 + 128*x**2*y*z - 144*x**2*y + 64*x**2*z**2 - 144*x**2*z + 76*x**2 - 16*x*y**2 - 32*x*y*z + 28*x*y - 16*x*z**2 + 28*x*z - 12*x,  # noqa: E501
+                -128*x**4/3 - 128*x**3*y/3 - 128*x**3*z/3 + 224*x**3/3 + 32*x**2*y + 32*x**2*z - 112*x**2/3 - 16*x*y/3 - 16*x*z/3 + 16*x/3,  # noqa: E501
+                128*x**2*y*z - 32*x*y*z,
+                128*x*y**2*z - 32*x*y*z,
+                128*x*y*z**2 - 32*x*y*z,
+                128*x**2*y*z + 256*x*y**2*z + 256*x*y*z**2 - 224*x*y*z + 128*y**3*z + 256*y**2*z**2 - 224*y**2*z + 128*y*z**3 - 224*y*z**2 + 96*y*z,  # noqa: E501
+                -128*x*y**2*z + 32*x*y*z - 128*y**3*z - 128*y**2*z**2 + 160*y**2*z + 32*y*z**2 - 32*y*z,
+                -128*x*y*z**2 + 32*x*y*z - 128*y**2*z**2 + 32*y**2*z - 128*y*z**3 + 160*y*z**2 - 32*y*z,
+                128*x**3*z + 256*x**2*y*z + 256*x**2*z**2 - 224*x**2*z + 128*x*y**2*z + 256*x*y*z**2 - 224*x*y*z + 128*x*z**3 - 224*x*z**2 + 96*x*z,  # noqa: E501
+                -128*x**3*z - 128*x**2*y*z - 128*x**2*z**2 + 160*x**2*z + 32*x*y*z + 32*x*z**2 - 32*x*z,
+                -128*x**2*z**2 + 32*x**2*z - 128*x*y*z**2 + 32*x*y*z - 128*x*z**3 + 160*x*z**2 - 32*x*z,
+                128*x**3*y + 256*x**2*y**2 + 256*x**2*y*z - 224*x**2*y + 128*x*y**3 + 256*x*y**2*z - 224*x*y**2 + 128*x*y*z**2 - 224*x*y*z + 96*x*y,  # noqa: E501
+                -128*x**3*y - 128*x**2*y**2 - 128*x**2*y*z + 160*x**2*y + 32*x*y**2 + 32*x*y*z - 32*x*y,
+                -128*x**2*y**2 + 32*x**2*y - 128*x*y**3 - 128*x*y**2*z + 160*x*y**2 + 32*x*y*z - 32*x*y,
+                -256*x**2*y*z - 256*x*y**2*z - 256*x*y*z**2 + 256*x*y*z
+            ]
 
-        mat = numpy.empty((len(pt), len(funcs)), dtype=object)
-        for i, f in enumerate(funcs):
-            for j, p in enumerate(pt):
-                mat[i, j] = f.subs([(x, p[0])])
-    elif celltype == basix.CellType.triangle:
-        for i in range(n + 1):
-            for j in range(n + 1 - i):
-                funcs += [x**j * y**i]
-
-        mat = numpy.empty((len(pt), len(funcs)), dtype=object)
-        for i, f in enumerate(funcs):
-            for j, p in enumerate(pt):
-                mat[i, j] = f.subs([(x, p[0]), (y, p[1])])
-    elif celltype == basix.CellType.tetrahedron:
-        for i in range(n + 1):
-            for j in range(n + 1 - i):
-                for k in range(n + 1 - i - j):
-                    funcs += [x**j * y**i * z**k]
-
-        mat = numpy.empty((len(pt), len(funcs)), dtype=object)
-        for i, f in enumerate(funcs):
-            for j, p in enumerate(pt):
-                mat[i, j] = f.subs([(x, p[0]), (y, p[1]), (z, p[2])])
-
-    mat = sympy.Matrix(mat)
-    mat = mat.inv()
-    g = []
-    for r in range(mat.shape[0]):
-        g += [sum([v * funcs[i] for i, v in enumerate(mat.row(r))])]
-
-    return g
+    raise NotImplementedError
 
 
 def test_point():
@@ -186,7 +291,7 @@ def test_lagrange(celltype, degree):
                                     basix.LagrangeVariant.equispaced)
     pts = basix.create_lattice(celltype[0], 6, basix.LatticeType.equispaced, True)
     w = lagrange.tabulate(0, pts)[0]
-    assert(numpy.isclose(numpy.sum(w, axis=1), 1.0).all())
+    assert numpy.isclose(numpy.sum(w, axis=1), 1.0).all()
 
 
 @pytest.mark.parametrize("degree", [1, 2, 3, 4])
@@ -284,7 +389,7 @@ def test_celltypes(degree, celltype):
     pts = basix.create_lattice(celltype, 5,
                                basix.LatticeType.equispaced, True)
     w = tp.tabulate(0, pts)[0]
-    assert(numpy.allclose(numpy.sum(w, axis=1), 1.0))
+    assert numpy.allclose(numpy.sum(w, axis=1), 1.0)
 
 
 def leq(a, b):
@@ -308,20 +413,26 @@ def in_cell(celltype, p):
 
 @pytest.mark.parametrize("variant", [
     basix.LagrangeVariant.equispaced,
-    basix.LagrangeVariant.gll_warped, basix.LagrangeVariant.gll_isaac, basix.LagrangeVariant.gll_centroid,
-    basix.LagrangeVariant.chebyshev_warped, basix.LagrangeVariant.chebyshev_isaac,
+    basix.LagrangeVariant.gll_warped,
+    basix.LagrangeVariant.gll_isaac,
+    basix.LagrangeVariant.gll_centroid,
+    basix.LagrangeVariant.chebyshev_warped,
+    basix.LagrangeVariant.chebyshev_isaac,
     basix.LagrangeVariant.chebyshev_centroid,
-    basix.LagrangeVariant.gl_warped, basix.LagrangeVariant.gl_isaac, basix.LagrangeVariant.gl_centroid,
+    basix.LagrangeVariant.gl_warped,
+    basix.LagrangeVariant.gl_isaac,
+    basix.LagrangeVariant.gl_centroid,
     basix.LagrangeVariant.vtk
 ])
 @pytest.mark.parametrize("celltype", [
-    basix.CellType.triangle, basix.CellType.tetrahedron,
-    basix.CellType.quadrilateral, basix.CellType.hexahedron,
+    basix.CellType.triangle,
+    basix.CellType.tetrahedron,
+    basix.CellType.quadrilateral,
+    basix.CellType.hexahedron,
 ])
 @pytest.mark.parametrize("degree", range(1, 5))
 def test_variant_points(celltype, degree, variant):
     e = basix.create_element(basix.ElementFamily.P, celltype, degree, variant, True)
-
     for p in e.points:
         assert in_cell(celltype, p)
 
@@ -336,8 +447,8 @@ def test_variant_points(celltype, degree, variant):
     basix.CellType.quadrilateral, basix.CellType.hexahedron,
 ])
 def test_continuous_lagrange(celltype, variant):
-    # The variants used in this test can only be used for discontinuous Lagrange,
-    # so trying to create them should throw a runtime error
+    # The variants used in this test can only be used for discontinuous
+    # Lagrange, so trying to create them should throw a runtime error
     with pytest.raises(RuntimeError):
         basix.create_element(basix.ElementFamily.P, celltype, 4, variant, False)
 
